ReqInt.min constructor
Constrains data to integer numbers greater than or equal to min.
min the smallest valid integer number.
blank the error message in case of a null or empty input value.
mal "malformed", the error message for non-integer input values.
small the error message if an input is too small.
Implementation
ReqInt.min(int min, {String? blank, String? mal, String? small})
: this._int(Int.min(min, mal: mal, small: small), blank);